@@ -45,7 +45,7 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGAdviceBoardWidget();
+    ~SKGAdviceBoardWidget() override;
 
     /**
      * Get the current state
@@ -53,14 +53,14 @@ public:
      * @return a string containing all information needed to set the same state.
      * Could be an XML stream
      */
-    virtual QString getState() override;
+    QString getState() override;
 
     /**
      * Set the current state
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    virtual void setState(const QString& iState) override;
+    void setState(const QString& iState) override;
 
 Q_SIGNALS:
     void refreshNeeded();
