@@ -23,7 +23,6 @@
 
 #include <qfileinfo.h>
 
-#include <ktipdialog.h>
 #include <klocalizedstring.h>
 
 #include "skgtraces.h"
@@ -43,6 +42,9 @@ SKGTipOfDayBoardWidget::SKGTipOfDayBoardWidget(QWidget* iParent, SKGDocument* iD
     onModified();
 
     connect(ui.kIcon, &QPushButton::clicked, this, &SKGTipOfDayBoardWidget::onModified);
+    connect(ui.kText, &QLabel::linkActivated, this, [ = ](const QString & val) {
+        SKGMainPanel::getMainPanel()->openPage(val);
+    });
 
     // Refresh
     connect(getDocument(), &SKGDocument::transactionSuccessfullyEnded, this, &SKGTipOfDayBoardWidget::onModified, Qt::QueuedConnection);
@@ -55,8 +57,5 @@ SKGTipOfDayBoardWidget::~SKGTipOfDayBoardWidget()
 
 void SKGTipOfDayBoardWidget::onModified()
 {
-    KTipDatabase db(QFileInfo(SKGMainPanel::getMainPanel()->getTipOfDayFileName()).fileName());
-    db.nextTip();
-    ui.kText->setText(SKGServices::htmlToString(db.tip()));
+    ui.kText->setText(SKGMainPanel::getMainPanel()->getTipOfDay());
 }
-
