@@ -132,7 +132,7 @@ void SKGDeletePlugin::onDelete()
     }
 
     // Display error
-    SKGMainPanel::displayErrorMessage(err);
+    SKGMainPanel::displayErrorMessage(err, true);
 }
 
 #include <skgdeleteplugin.moc>
