@@ -42,27 +42,26 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGDeletePlugin();
+    ~SKGDeletePlugin() override;
 
     /**
      * Called to initialise the plugin
      * @param iDocument the main document
-     * @param iArgument the arguments
      * @return true if the plugin is compatible with the document
      */
-    virtual bool setupActions(SKGDocument* iDocument, const QStringList& iArgument) override;
+    bool setupActions(SKGDocument* iDocument) override;
 
     /**
      * The title of the plugin.
      * @return The title of the plugin
      */
-    virtual QString title() const override;
+    QString title() const override;
 
     /**
      * Must be implemented to set the position of the plugin.
      * @return integer value between 0 and 999 (default = 999)
      */
-    virtual int getOrder() const override;
+    int getOrder() const override;
 
 private Q_SLOTS:
     void onDelete();
