@@ -59,9 +59,9 @@ public:
     /**
      * This function is called when the application is launched again with new arguments
      * @param iArgument the arguments
-     * @return true if the arguments have been processed
+     * @return the rest of arguments to treat
      */
-    bool processArguments(const QStringList& iArgument) override;
+    QStringList processArguments(const QStringList& iArgument) override;
 
     /**
      * The preference widget of the plugin.
