@@ -518,7 +518,7 @@ SKGError SKGImportPluginQif::importFile()
                                 bool ok;
                                 int number = val.toInt(&ok);
                                 if (ok && number != 0) {
-                                    err = currentOperation.setNumber(number);
+                                    err = currentOperation.setNumber(val);
                                 } else {
                                     err = currentOperation.setMode(val);
                                 }
@@ -1006,8 +1006,8 @@ SKGError SKGImportPluginQif::exportFile()
                         }
 
                         if (!investment) {
-                            int number = operation.getNumber();
-                            if (number) {
+                            auto number = operation.getNumber();
+                            if (!number.isEmpty()) {
                                 stream << 'N' << operation.getNumber() << endl;
                             }
                         } else {
