@@ -443,6 +443,10 @@ void SKGBankPluginWidget::onIconChanged()
     } else {
         ui.kAccountCreatorBank->setText(QStringLiteral(""));
     }
+
+    // Facilitate bank number
+    QString code = ui.kAccountCreatorIcon->itemData(ui.kAccountCreatorIcon->currentIndex()).toString();
+    ui.kAccountCreatorBankNumber->setText(code);
 }
 
 void SKGBankPluginWidget::onAccountCreatorModified()
@@ -475,12 +479,6 @@ void SKGBankPluginWidget::onAccountCreatorModified()
     ui.kAccountCreatorBank->setVisible(!wallet);
     ui.kAccountCreatorAddress->setVisible(!wallet);
     ui.kAgencyAddressLbl->setVisible(!wallet);
-
-    // Facilitate bank number
-    if (ui.kAccountCreatorBankNumber->text().isEmpty()) {
-        QString code = ui.kAccountCreatorIcon->itemData(ui.kAccountCreatorIcon->currentIndex()).toString();
-        ui.kAccountCreatorBankNumber->setText(code);
-    }
 }
 
 SKGError SKGBankPluginWidget::setInitialBalanceFromEditor(SKGAccountObject& iAccount)
@@ -592,7 +590,7 @@ void SKGBankPluginWidget::onModifyAccountClicked()
                 }
             }
 
-            // Is it a massive modification of payees to merge them ?
+            // Is it a massive modification of account to merge them ?
             if (nb > 1) {
                 if (!messageSent) {
                     getDocument()->sendMessage(i18nc("Information message", "You tried to modify all names of selected accounts. Accounts have been merged."));
@@ -602,7 +600,7 @@ void SKGBankPluginWidget::onModifyAccountClicked()
                 SKGAccountObject accountObj1(selection[0]);
                 for (int i = 1; !err && i < nb; ++i) {
                     SKGAccountObject accountObj(selection.at(i));
-                    err = accountObj1.merge(accountObj);
+                    err = accountObj1.merge(accountObj, true);
                 }
 
                 // Change selection for the rest of the operation
