@@ -477,7 +477,7 @@ void SKGCalculatorPluginWidget::onAdd()
     }
 
     // Display error
-    SKGMainPanel::displayErrorMessage(err);
+    SKGMainPanel::displayErrorMessage(err, true);
 }
 
 void SKGCalculatorPluginWidget::onUpdate()
@@ -520,7 +520,7 @@ void SKGCalculatorPluginWidget::onUpdate()
     }
 
     // Display error
-    SKGMainPanel::displayErrorMessage(err);
+    SKGMainPanel::displayErrorMessage(err, true);
 }
 
 void SKGCalculatorPluginWidget::onAmortizationComputationDelayed()
