@@ -45,7 +45,7 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGCalculatorPluginWidget();
+    ~SKGCalculatorPluginWidget() override;
 
     /**
      * Get the current state
@@ -53,46 +53,46 @@ public:
      * @return a string containing all information needed to set the same state.
      * Could be an XML stream
      */
-    virtual QString getState() override;
+    QString getState() override;
 
     /**
      * Set the current state
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    virtual void setState(const QString& iState) override;
+    void setState(const QString& iState) override;
 
     /**
      * Get attribute name to save the default state
      * MUST BE OVERWRITTEN
      * @return attribute name to save the default state.
      */
-    virtual QString getDefaultStateAttribute() override;
+    QString getDefaultStateAttribute() override;
 
     /**
      * Get the current selection
      * @return selected objects
      */
-    virtual SKGObjectBase::SKGListSKGObjectBase getSelectedObjects() override;
+    SKGObjectBase::SKGListSKGObjectBase getSelectedObjects() override;
 
     /**
      * Get the number of seleted object
      * @return number of selected objects
      */
-    virtual int getNbSelectedObjects() override;
+    int getNbSelectedObjects() override;
 
     /**
      * Get the zoomable widget.
      * The default implementation returns the main widget.
      * @return the zoomable widget.
      */
-    virtual QWidget* zoomableWidget() override;
+    QWidget* zoomableWidget() override;
 
     /**
      * Get the main widget
      * @return a widget
      */
-    virtual QWidget* mainWidget() override;
+    QWidget* mainWidget() override;
 
 protected:
     /**
@@ -101,7 +101,7 @@ protected:
      * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* iObject, QEvent* iEvent) override;
+    bool eventFilter(QObject* iObject, QEvent* iEvent) override;
 
 private Q_SLOTS:
     void dataModified(const QString& iTableName, int iIdTransaction);
