@@ -260,7 +260,7 @@ void SKGCategoriesPluginWidget::onAddCategory()
         IFOKDO(err, cat.getDocument()->sendMessage(i18nc("An information message", "The category '%1' has been created", cat.getDisplayName()), SKGDocument::Hidden));
     }
 
-// status bar
+    // status bar
     IFOK(err) {
         ui.kCategoriesView->getView()->selectObject(cat.getUniqueID());
         err = SKGError(0, i18nc("Successful message after an user action", "Category '%1' created", name));
@@ -269,7 +269,7 @@ void SKGCategoriesPluginWidget::onAddCategory()
     }
 
     // Display error
-    SKGMainPanel::displayErrorMessage(err);
+    SKGMainPanel::displayErrorMessage(err, true);
 }
 
 void SKGCategoriesPluginWidget::onUpdateCategory()
@@ -322,7 +322,7 @@ void SKGCategoriesPluginWidget::onUpdateCategory()
     }
 
     // Display error
-    SKGMainPanel::displayErrorMessage(err);
+    SKGMainPanel::displayErrorMessage(err, true);
 
     // Set focus on table
     ui.kCategoriesView->getView()->setFocus();
