@@ -103,7 +103,7 @@ void SKGReportBoardWidget::dataModified(const QString& iTableName, int iIdTransa
         bool exist = false;
         getDocument()->existObjects(QStringLiteral("account"), QStringLiteral(""), exist);
         if (parentWidget()) {
-            parentWidget()->setVisible(exist);
+            setVisible(exist);
         }
     }
 }
