@@ -39,8 +39,8 @@
  */
 static const int FORECASTMAX = 100;
 
-SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iMinimmumMode)
-    : SKGTabPage(iDocument), m_openReportAction(nullptr), m_openAction(nullptr), m_mode(0), m_nbLevelLines(0), m_nbLevelColumns(0), m_refreshNeeded(true)
+SKGReportPluginWidget::SKGReportPluginWidget(QWidget* iParent, SKGDocumentBank* iDocument, bool iMinimmumMode)
+    : SKGTabPage(iParent, iDocument), m_openReportAction(nullptr), m_openAction(nullptr), m_mode(0), m_nbLevelLines(0), m_nbLevelColumns(0), m_refreshNeeded(true)
 {
     SKGTRACEINFUNC(10);
     if (!iDocument) {
@@ -954,10 +954,18 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                         if (nbBudgets) {
                             // Get most active account
                             SKGStringListList list;
-                            err = doc->executeSelectSqliteOrder(QStringLiteral("SELECT IFNULL((SELECT account.id FROM account, operation WHERE +operation.rd_account_id=account.id AND d_date>date('now', '-3 month') GROUP BY (t_name) ORDER BY COUNT(1) DESC LIMIT 1), (SELECT id FROM account)) "), list);
-                            if (!err && list.count() == 2) {
-                                SKGAccountObject account(doc, SKGServices::stringToInt(list.at(1).at(0)));
-                                err = account.load();
+                            err = doc->executeSelectSqliteOrder(QStringLiteral("SELECT  rd_account_id, r_category_id FROM v_suboperation_consolidated WHERE d_date>date('now', '-3 month') group by r_category_id, rd_account_id order by count(rd_account_id) DESC"), list);
+                            int nbmap = list.count();
+                            if (!err && nbmap >= 2) {
+                                // Build map
+                                int default_account = 0;
+                                QMap<int, int> category_account;
+                                for (int i = 1; i < nbmap; ++i) {
+                                    if (i == 1) {
+                                        default_account = SKGServices::stringToInt(list.at(i).at(0));
+                                    }
+                                    category_account[SKGServices::stringToInt(list.at(i).at(1))] = SKGServices::stringToInt(list.at(i).at(0));
+                                }
 
                                 // Get unit
                                 SKGUnitObject unit(doc);
@@ -974,6 +982,11 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                                     SKGCategoryObject cat;
                                     budget.getCategory(cat);
 
+                                    // Get better account for the category
+                                    SKGAccountObject account(doc, category_account.contains(cat.getID()) ? category_account[cat.getID()] : default_account);
+                                    account.load();
+
+
                                     SKGOperationObject op;
                                     IFOKDO(err, account.addOperation(op))
                                     IFOKDO(err, op.setDate(QDate(budget.getYear(), qMax(budget.getMonth(), 1), 1)))
