@@ -135,31 +135,31 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
     connect(ui.kUnitOpen, &QPushButton::clicked, this, &SKGUnitPluginWidget::onOpenURL);
 
     auto downloadLastAction = new QAction(SKGServices::fromTheme(QStringLiteral("download")), i18n("download last value only"), this);
-    downloadLastAction->setData(SKGUnitObject::LAST);
+    downloadLastAction->setData(int(SKGUnitObject::LAST));
     connect(downloadLastAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
     auto downloadLastMonthlyAction = new QAction(SKGServices::fromTheme(QStringLiteral("download")), i18n("download monthly values since last known value"), this);
-    downloadLastMonthlyAction->setData(SKGUnitObject::LAST_MONTHLY);
+    downloadLastMonthlyAction->setData(int(SKGUnitObject::LAST_MONTHLY));
     connect(downloadLastMonthlyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
     auto downloadLastWeeklyAction = new QAction(SKGServices::fromTheme(QStringLiteral("download")), i18n("download weekly values since last known value"), this);
-    downloadLastWeeklyAction->setData(SKGUnitObject::LAST_WEEKLY);
+    downloadLastWeeklyAction->setData(int(SKGUnitObject::LAST_WEEKLY));
     connect(downloadLastWeeklyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
     auto downloadLastDailyAction = new QAction(SKGServices::fromTheme(QStringLiteral("download")), i18n("download daily values since last known value"), this);
-    downloadLastDailyAction->setData(SKGUnitObject::LAST_DAILY);
+    downloadLastDailyAction->setData(int(SKGUnitObject::LAST_DAILY));
     connect(downloadLastDailyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
     auto downloadMonthlyAction = new QAction(SKGServices::fromTheme(QStringLiteral("download")), i18n("download all monthly values"), this);
-    downloadMonthlyAction->setData(SKGUnitObject::ALL_MONTHLY);
+    downloadMonthlyAction->setData(int(SKGUnitObject::ALL_MONTHLY));
     connect(downloadMonthlyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
     auto downloadWeeklyAction = new QAction(SKGServices::fromTheme(QStringLiteral("download")), i18n("download all weekly values"), this);
-    downloadWeeklyAction->setData(SKGUnitObject::ALL_WEEKLY);
+    downloadWeeklyAction->setData(int(SKGUnitObject::ALL_WEEKLY));
     connect(downloadWeeklyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
     auto downloadDailyAction = new QAction(SKGServices::fromTheme(QStringLiteral("download")), i18n("download all daily values"), this);
-    downloadDailyAction->setData(SKGUnitObject::ALL_DAILY);
+    downloadDailyAction->setData(int(SKGUnitObject::ALL_DAILY));
     connect(downloadDailyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
     auto simplifyAction = new QAction(SKGServices::fromTheme(QStringLiteral("edit-delete")), i18n("simplify values"), this);
@@ -199,12 +199,12 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
     connect(ui.kWidgetSelector, &SKGWidgetSelector::selectedModeChanged, this, &SKGUnitPluginWidget::onUnitCreatorModified);
 
     // Fill combo box for type
-    ui.kTypeCreatorUnit->addItem(i18nc("Noun", "Primary currency"), SKGUnitObject::PRIMARY);
-    ui.kTypeCreatorUnit->addItem(i18nc("Noun", "Secondary currency"), SKGUnitObject::SECONDARY);
-    ui.kTypeCreatorUnit->addItem(i18nc("Noun, a country's currency", "Currency"), SKGUnitObject::CURRENCY);
-    ui.kTypeCreatorUnit->addItem(i18nc("Noun, a financial share, as in a stock market", "Share"), SKGUnitObject::SHARE);
-    ui.kTypeCreatorUnit->addItem(i18nc("Noun, a financial index like the Dow Jones, NASDAQ, CAC40...", "Index"), SKGUnitObject::INDEX);
-    ui.kTypeCreatorUnit->addItem(i18nc("Noun, a physical object like a house or a car", "Object"), SKGUnitObject::OBJECT);
+    ui.kTypeCreatorUnit->addItem(i18nc("Noun", "Primary currency"), int(SKGUnitObject::PRIMARY));
+    ui.kTypeCreatorUnit->addItem(i18nc("Noun", "Secondary currency"), int(SKGUnitObject::SECONDARY));
+    ui.kTypeCreatorUnit->addItem(i18nc("Noun, a country's currency", "Currency"), int(SKGUnitObject::CURRENCY));
+    ui.kTypeCreatorUnit->addItem(i18nc("Noun, a financial share, as in a stock market", "Share"), int(SKGUnitObject::SHARE));
+    ui.kTypeCreatorUnit->addItem(i18nc("Noun, a financial index like the Dow Jones, NASDAQ, CAC40...", "Index"), int(SKGUnitObject::INDEX));
+    ui.kTypeCreatorUnit->addItem(i18nc("Noun, a physical object like a house or a car", "Object"), int(SKGUnitObject::OBJECT));
     bool primaryUnit, secondaryUnit;
     iDocument->existObjects(QStringLiteral("unit"), QStringLiteral("t_type='1'"), primaryUnit);
     iDocument->existObjects(QStringLiteral("unit"), QStringLiteral("t_type='2'"), secondaryUnit);
@@ -317,7 +317,7 @@ void SKGUnitPluginWidget::onSelectionChanged()
         ui.kNameCreatorUnit->setText(unit.getName());
         ui.kSymbolCreatorUnit->setText(unit.getSymbol());
         ui.kCountryCreatorUnit->setText(unit.getCountry());
-        ui.kTypeCreatorUnit->setCurrentIndex(ui.kTypeCreatorUnit->findData(unit.getType()));
+        ui.kTypeCreatorUnit->setCurrentIndex(ui.kTypeCreatorUnit->findData(int(unit.getType())));
         ui.kInternetCreatorUnit->setText(unit.getInternetCode());
         ui.kUnitCreatorUnit->setText(unit.getAttribute(QStringLiteral("t_UNIT")));
         ui.kNbDecimal->setValue(unit.getNumberDecimal());
@@ -484,7 +484,7 @@ void SKGUnitPluginWidget::onAddUnit()
     }
 
     // Display error
-    SKGMainPanel::displayErrorMessage(err);
+    SKGMainPanel::displayErrorMessage(err, true);
 }
 
 void SKGUnitPluginWidget::onModifyUnit()
@@ -498,28 +498,47 @@ void SKGUnitPluginWidget::onModifyUnit()
 
     {
         SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Unit update"), err, nb);
+        auto name = ui.kNameCreatorUnit->text();
+        if (name != NOUPDATE && !name.startsWith(QLatin1String("="))) {
+            // Is this name already existing?
+            bool messageSent = false;
+            SKGUnitObject p(getDocument());
+            p.setName(name);
+            IFOK(p.load()) {
+                if (selection.indexOf(p) == -1) {
+                    // We will have to merge with the existing unit
+                    selection.insert(0, p);
+                    nb++;
 
-        // Is it a massive modification of payees to merge them ?
-        if (nb > 1 && ui.kNameCreatorUnit->text() != NOUPDATE && !ui.kNameCreatorUnit->text().startsWith(QLatin1String("="))) {
-            getDocument()->sendMessage(i18nc("Information message", "You tried to modify all names of selected units. Units have been merged."));
-
-            // Do the merge
-            SKGUnitObject unitObj1(selection[0]);
-            for (int i = 1; !err && i < nb; ++i) {
-                SKGUnitObject unitObj(selection.at(i));
-                err = unitObj1.merge(unitObj);
+                    getDocument()->sendMessage(i18nc("Information message", "You tried to modify names of selected units to an existing unit. Units have been merged."));
+                    messageSent = true;
+                }
             }
 
-            // Change selection for the rest of the operation
-            selection.clear();
-            selection.push_back(unitObj1);
-            nb = 1;
+            // Is it a massive modification of payees to merge them ?
+            if (nb > 1) {
+                if (!messageSent) {
+                    getDocument()->sendMessage(i18nc("Information message", "You tried to modify all names of selected units. Units have been merged."));
+                }
+
+                // Do the merge
+                SKGUnitObject unitObj1(selection[0]);
+                for (int i = 1; !err && i < nb; ++i) {
+                    SKGUnitObject unitObj(selection.at(i));
+                    err = unitObj1.merge(unitObj);
+                }
+
+                // Change selection for the rest of the operation
+                selection.clear();
+                selection.push_back(unitObj1);
+                nb = 1;
+            }
         }
 
         for (int i = 0; !err && i < nb; ++i) {
             // Modification of unit object
             SKGUnitObject unitObj(selection.at(i));
-            IFOKDO(err, unitObj.setName(ui.kNameCreatorUnit->text()))
+            IFOKDO(err, unitObj.setName(name))
             IFOKDO(err, unitObj.setSymbol(ui.kSymbolCreatorUnit->text()))
             IFOKDO(err, unitObj.setCountry(ui.kCountryCreatorUnit->text()))
             IFOKDO(err, unitObj.setInternetCode(ui.kInternetCreatorUnit->text()))
@@ -549,7 +568,7 @@ void SKGUnitPluginWidget::onModifyUnit()
     }
 
     // Display error
-    SKGMainPanel::displayErrorMessage(err);
+    SKGMainPanel::displayErrorMessage(err, true);
 
     // Set focus on table
     ui.kUnitTableViewEdition->getView()->setFocus();
