@@ -778,12 +778,59 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
             } else if (att == QStringLiteral("t_REFUND") || att == QStringLiteral("t_REALREFUND")) {
                 QString trackerName = obj->getAttribute(att);
                 if (!trackerName.isEmpty()) {
-                    SKGTrackerObject tracker(SKGObjectBase(getDocument(), QStringLiteral("v_refund")));
+                    SKGTrackerObject tracker(getDocument());
                     tracker.setName(trackerName);
                     tracker.load();
                     SKGServices::SKGUnitInfo unit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
                     toolTipString = SKGServices::toCurrencyString(tracker.getCurrentAmount(), unit.Symbol, unit.NbDecimal);
                 }
+            } else if (att == QStringLiteral("t_PAYEE")) {
+                QString payeeName = obj->getAttribute(att);
+                if (!payeeName.isEmpty()) {
+                    SKGPayeeObject payee(getDocument());
+                    payee.setName(payeeName);
+                    payee.load();
+
+                    auto address = payee.getAddress();
+                    if (!address.isEmpty()) {
+                        toolTipString += i18nc("Information", "Address= %1\n", address);
+                    }
+
+                    auto c = payee.getAttribute(QStringLiteral("t_CATEGORY"));
+                    if (c.isEmpty()) {
+                        c = static_cast<SKGDocumentBank*>(getDocument())->getCategoryForPayee(payeeName);
+                    }
+                    if (!c.isEmpty()) {
+                        toolTipString += i18nc("Information", "Category= %1\n", c);
+                    }
+                }
+            }  else if (att == QStringLiteral("t_ACCOUNT")  || att == QStringLiteral("t_TOACCOUNT")) {
+                QString accountName = obj->getAttribute(att);
+                if (!accountName.isEmpty()) {
+                    SKGAccountObject account(getDocument());
+                    account.setName(accountName);
+                    account.load();
+
+                    auto tmp = account.getAgencyNumber();
+                    if (!tmp.isEmpty()) {
+                        toolTipString += i18nc("Information", "Agency number= %1\n", tmp);
+                    }
+
+                    tmp = account.getNumber();
+                    if (!tmp.isEmpty()) {
+                        toolTipString += i18nc("Information", "Number= %1\n", tmp);
+                    }
+
+                    tmp = account.getAgencyAddress();
+                    if (!tmp.isEmpty()) {
+                        toolTipString += i18nc("Information", "Address= %1\n", tmp);
+                    }
+
+                    tmp = account.getComment();
+                    if (!tmp.isEmpty()) {
+                        toolTipString += i18nc("Information", "Comment= %1\n", tmp);
+                    }
+                }
             } else if (att == QStringLiteral("t_CATEGORY")) {
                 SKGOperationObject op(*obj);
                 if (m_recurrentoperationTable) {
