@@ -91,6 +91,11 @@ Q_SIGNALS:
      */
     void editingFinished();
 
+    /**
+     * Sent when edition changed
+     */
+    void xmlDescriptionChanged();
+
 protected :
     /**
      * Event filtering
