@@ -36,7 +36,7 @@ class SKGBANKGUI_EXPORT SKGUnitComboBox : public SKGComboBox
     /**
      * the current unit
      */
-    Q_PROPERTY(SKGUnitObject unit READ getUnit WRITE setUnit)
+    Q_PROPERTY(SKGUnitObject unit READ getUnit WRITE setUnit NOTIFY unitChanged)
 
 public:
     /**
@@ -81,6 +81,12 @@ public Q_SLOTS:
      */
     virtual void refershList();
 
+Q_SIGNALS:
+    /**
+     * Emitted when the unit is changed
+     */
+    void unitChanged();
+
 private Q_SLOTS:
     void dataModified(const QString& iTableName, int iIdTransaction);
 
