@@ -954,7 +954,7 @@ QVector< QVector<SKGOperationObject> > SKGAccountObject::getPossibleReconciliati
                 }
 
                 ++index;
-            } while (std::next_permutation(v.begin(), v.end()) && !stopTests);
+            } while (index < nb && std::next_permutation(v.begin(), v.end()) && !stopTests);
 
             // Try to find next solutions
             auto reconciliations = getPossibleReconciliations(iOperations.mid(nbNext), nextBalance, iTargetBalance, iUnit, iSearchAllPossibleReconciliation);
