@@ -462,10 +462,11 @@ public:
     /**
      * Merge iAccount in current account
      * @param iAccount the account. All operations will be transferred into this account. The account will be removed
+     * @param iMergeInitalBalance to merge the initial balances too
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError merge(const SKGAccountObject& iAccount);
+    virtual SKGError merge(const SKGAccountObject& iAccount, bool iMergeInitalBalance);
 
     /**
      * Create a transfert operation to balance a credit card account (based on pointed operations)
