@@ -196,14 +196,14 @@ QString SKGOperationObject::getComment() const
     return getAttribute(QStringLiteral("t_comment"));
 }
 
-SKGError SKGOperationObject::setNumber(qlonglong iNumber)
+SKGError SKGOperationObject::setNumber(const QString& iNumber)
 {
-    return setAttribute(QStringLiteral("i_number"), SKGServices::intToString(iNumber));
+    return setAttribute(QStringLiteral("t_number"), iNumber);
 }
 
-qlonglong SKGOperationObject::getNumber() const
+QString SKGOperationObject::getNumber() const
 {
-    return SKGServices::stringToInt(getAttribute(QStringLiteral("i_number")));
+    return getAttribute(QStringLiteral("t_number"));
 }
 
 SKGOperationObject::OperationStatus SKGOperationObject::getStatus() const
@@ -506,9 +506,7 @@ SKGError SKGOperationObject::mergeAttribute(const SKGOperationObject& iDeletedOn
     if (!err && !isBookmarked()) {
         err = bookmark(iDeletedOne.isBookmarked());
     }
-    if (!err && !getNumber()) {
-        err = setNumber(iDeletedOne.getNumber());
-    }
+    IFOKDO(err, setNumber(iDeletedOne.getNumber()))
     IFOKDO(err, save())
 
     // Merge suboperations
