@@ -80,7 +80,7 @@ public:
     /**
      * Destructor
      */
-    ~SKGRecurrentOperationObject();
+    ~SKGRecurrentOperationObject() override;
 
     /**
      * Get the parent operation
