@@ -230,6 +230,8 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
             addSql = QStringLiteral("t_imported='P'");
         } else if (iMode == IMPORTING) {
             addSql = QStringLiteral("t_imported='T'");
+        } else if (iMode == NOTCHECKED) {
+            addSql = QStringLiteral("t_status!='Y'");
         }
         QString wc = getSelectSqlOrder(addSql);
 
