@@ -56,7 +56,7 @@ namespace KPIM
 class SKGBASEGUI_EXPORT KDateEdit : public QComboBox // krazy:exclude=qclasses
 {
     Q_OBJECT
-    Q_PROPERTY(QDate date READ date WRITE setDate)
+    Q_PROPERTY(QDate date READ date WRITE setDate NOTIFY dateChanged)
 
 public:
     explicit KDateEdit(QWidget* iParent);
