@@ -89,17 +89,19 @@ public:
     /**
      * Display an error message
      * @param iError the error
+     * @param iNotifyIfNoError to launch a notification even if there is no error
      * @return the message widget
      */
-    static KMessageWidget* displayErrorMessage(const SKGError& iError);
+    static KMessageWidget* displayErrorMessage(const SKGError& iError, bool iNotifyIfNoError = false);
 
     /**
      * Display an error message
      * @param iError the error
      * @param iAction the additional action to add
+     * @param iNotifyIfNoError to launch a notification even if there is no error
      * @return the message widget
      */
-    static KMessageWidget* displayErrorMessage(const SKGError& iError, QAction* iAction);
+    static KMessageWidget* displayErrorMessage(const SKGError& iError, QAction* iAction, bool iNotifyIfNoError = false);
 
     /**
      * Fill a widget with distinct values
@@ -510,6 +512,7 @@ protected:
     bool eventFilter(QObject* iObject, QEvent* iEvent) override;
 
 private Q_SLOTS:
+    KMessageWidget* getMessageWidget(const QString& iMessage, SKGDocument::MessageType iType, const QString& iAction, bool iAutoKillOnClick);
     void showMenu(const QPoint iPos);
 
     void onSettingsChanged();
