@@ -114,7 +114,7 @@ bool SKGSortFilterProxyModel::lessThan(const QModelIndex& left,
         QVariant rightData = model->data(model->index(right.row(), d->m_current, right.parent()), Qt::UserRole);
         SKGObjectBase* leftObj = model->getObjectPointer(left);
         if (leftData == rightData && leftObj) {
-            if (leftObj->getTable().isEmpty() && d->m_current != 0) {
+            if (leftObj->getTable().isEmpty() && d->m_current != 0 && !d->m_insubsort) {
                 // Groups
                 d->m_insubsort = true;
                 bool test = SKGSortFilterProxyModel::lessThan(model->index(left.row(), 0), model->index(right.row(), 0));
@@ -122,7 +122,7 @@ bool SKGSortFilterProxyModel::lessThan(const QModelIndex& left,
                 return test;
             }
             // Compare on previous column
-            if (!d->m_insubsort && d->m_previous != -1) {
+            if (!d->m_insubsort && d->m_previous != -1 && !d->m_insubsort) {
                 d->m_insubsort = true;
                 auto vl = model->index(left.row(), d->m_previous, left.parent());
                 auto vr = model->index(right.row(), d->m_previous, right.parent());
