@@ -384,6 +384,12 @@ public Q_SLOTS:
      */
     virtual bool swithOriginVisibility();
 
+    /**
+     * Switch the decimals visibility
+     * @return the new visibility
+     */
+    virtual bool swithDecimalsVisibility();
+
     /**
      * Reset the colors
      */
@@ -463,6 +469,7 @@ private:
     bool m_tableVisible;
     bool m_textVisible;
     bool m_zeroVisible;
+    bool m_decimalsVisible;
     bool m_shadow;
 
     QMenu* m_mainMenu;
@@ -474,6 +481,7 @@ private:
     QAction* m_actShowPareto;
     QAction* m_actShowLegend;
     QAction* m_actShowZero;
+    QAction* m_actShowDecimal;
     QAction* m_allPositiveMenu;
     QWidgetAction* m_displayModeWidget;
 
