@@ -34,12 +34,12 @@ class SKGBASEGUI_EXPORT SKGZoomSelector : public QWidget
     /**
      * Value of the zoom
      */
-    Q_PROPERTY(int value READ value WRITE setValue USER true)
+    Q_PROPERTY(int value READ value WRITE setValue NOTIFY changed USER true)
 
     /**
      * Value of the zoom
      */
-    Q_PROPERTY(int resetValue READ resetValue WRITE setResetValue)
+    Q_PROPERTY(int resetValue READ resetValue WRITE setResetValue NOTIFY changed)
 
 public:
     /**
