@@ -180,6 +180,15 @@ public:
      */
     virtual SKGError setProgressCallback(int (*iProgressFunction)(int, qint64, const QString&, void*), void* iData);
 
+    /**
+     * Add a check function at the end of successfully executed transaction.
+     * If an error is returned, the transaction will be cancelled.
+     * @param iCheckFunction the pointer of the function
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError addEndOfTransactionCheck(SKGError(*iCheckFunction)(SKGDocument*));
+
     /**
      * Get unique identifier
      * @return the unique identifier
