@@ -31,6 +31,7 @@
 #include "skgdefine.h"
 
 typedef int (*progressFunction)(int, qint64, const QString&, void*);
+typedef SKGError(*checksFunction)(SKGDocument*);
 
 /**
 * This class manages skg documents
@@ -54,6 +55,7 @@ public:
 
     int m_lastSavedTransaction;
     progressFunction m_progressFunction;
+    QList<checksFunction> m_checkFunctions;
     void* m_progressData;
     QString m_currentFileName;
     QString m_databaseIdentifier;
