@@ -90,7 +90,7 @@ public:
      * Move constructor
      * @param iObject the object to copy
      */
-    explicit SKGObjectBase(SKGObjectBase&& iObject) noexcept;
+    SKGObjectBase(SKGObjectBase&& iObject) noexcept;
 
     /**
      * Operator comparison
@@ -136,7 +136,7 @@ public:
     /**
      * Destructor
      */
-    virtual ~SKGObjectBase();
+    ~SKGObjectBase() override;
 
     /**
      * Return the unique id of this object
