@@ -116,6 +116,8 @@ QString SKGServices::searchCriteriasToWhereClause(const SKGServices::SKGSearchCr
                 word = word.right(word.count() - pos - op.count());
             }
 
+            word = SKGServices::stringToSqlString(word);
+
             for (int j = 0; j < nbAttributes; ++j) {
                 QString attDatabase = iAttributes.at(j);
                 QString attForComparison = (iDocument ? iDocument->getDisplay(attDatabase) : attDatabase).toLower();
@@ -418,7 +420,7 @@ QString SKGServices::getNextString(const QString& iString)
         output = SKGServices::intToString(val + 1);
     } else {
         // This is a string
-        output = "";
+        output = QLatin1String("");
     }
     return output;
 }
