@@ -66,7 +66,7 @@ void SKGTESTActions::Test()
 
             // Search page
             << QStringLiteral("page_Skrooge search plugin") << QStringLiteral("edit_select_all")
-            << QStringLiteral("execute_all") << QStringLiteral("execute_imported") << QStringLiteral("execute_not_validated")
+            << QStringLiteral("execute_all") << QStringLiteral("execute_notchecked") << QStringLiteral("execute_imported") << QStringLiteral("execute_not_validated")
             << QStringLiteral("open_report")
 
             // All other pages
