@@ -304,7 +304,23 @@ int main(int argc, char** argv)
         SKGTESTERROR(QStringLiteral("ACCOUNT.load"), account.load(), true);
         SKGTEST(QStringLiteral("ACCOUNT:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("-2986.39"));
     }
+    {
+        // Test import 397055
+        SKGDocumentBank document1;
+        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true);
+        SKGError err;
+        {
+            // Scope of the transaction
+            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT"), err);
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportcsv/397055.csv"));
+            SKGTESTERROR(QStringLiteral("CSV.importFile"), imp1.importFile(), true);
+        }
 
+        SKGAccountObject account(&document1);
+        SKGTESTERROR(QStringLiteral("ACCOUNT.load"), account.setName(QStringLiteral("397055")), true);
+        SKGTESTERROR(QStringLiteral("ACCOUNT.load"), account.load(), true);
+        SKGTEST(QStringLiteral("ACCOUNT:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("50"));
+    }
     {
         // Test import with tabulation
         SKGDocumentBank document1;
